namespace IgDataPresenterHierarchyExport
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Runtime.CompilerServices;

    using IgDataPresenterHierarchyExport.Annotations;

    public class ExportData : INotifyPropertyChanged
    {
        private bool _includeInExport;

        public ExportData(int rowId, string title, bool includeInExport)
            : this(rowId, title, includeInExport, new List<ExportData>())
        {
        }

        public ExportData(int rowId, string title, bool includeInExport, IEnumerable<ExportData> children)
        {
            RowId = rowId;
            Title = title;
            Children = children;
            _includeInExport = includeInExport;
        }

        public int RowId { get; private set; }

        public string Title { get; private set; }

        public bool IncludeInExport
        {
            get
            {
                return _includeInExport;
            }

            set
            {
                if (!value.Equals(_includeInExport))
                {
                    _includeInExport = value;
                    OnPropertyChanged();
                }
            }
        }

        public IEnumerable<ExportData> Children { get; private set; }

        public event PropertyChangedEventHandler PropertyChanged;

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}