﻿namespace IgDataPresenterHierarchyExport
{
    using System;
    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using System.Globalization;
    using System.IO;
    using System.Linq;
    using System.Windows;

    using Infragistics.Windows.DataPresenter;
    using Infragistics.Windows.DataPresenter.ExcelExporter;

    using Microsoft.Office.Interop.Excel;
    using Infragistics.Documents.Excel;

    /// <summary>Interaction logic for Main Window</summary>
    public partial class MainWindow
    {
        private readonly DataPresenterExcelExporter _excelExporter = new DataPresenterExcelExporter();
        private readonly ExportOptions _exportOptions = new ExportOptions();
        private readonly ObservableCollection<ExportData> _source = new ObservableCollection<ExportData>
        {
            new ExportData(0, "First Row - Parent", false, new List<ExportData> { new ExportData(1, "First Child", true), new ExportData(2, "Second Child", true) }),
            new ExportData(3, "Second Row - Parent", true, new List<ExportData> { new ExportData(4, "First Child", true), new ExportData(5, "Second Child", true) })
        };

        public MainWindow()
        {
            InitializeComponent();
            DataContext = this;
            _excelExporter.InitializeRecord += _excelExporter_InitializeRecord;
            
        }

        void _excelExporter_InitializeRecord(object sender, InitializeRecordEventArgs e)
        {
            if (e != null && e.Record != null)
            { 
                var dataRecord = e.Record as DataRecord;
                if (dataRecord != null && dataRecord.HasChildren)
                {
                    e.SkipDescendants = true;
                }
            }

        }

        public IEnumerable<ExportData> Source
        {
            get
            {
                return _source;
            }
        }

        private static void OpenExcel(string filename, bool showExcel = true)
        {
            var excelApp = new Microsoft.Office.Interop.Excel.Application { Visible = showExcel, ScreenUpdating = false };

            excelApp.Workbooks.OpenText(filename, Other: true, TrailingMinusNumbers: true);
            var sheets = excelApp.Worksheets;
            foreach (var worksheet in sheets.Cast<Microsoft.Office.Interop.Excel.Worksheet>())
            {
                worksheet.UsedRange.Columns.AutoFit();
            }

            excelApp.ScreenUpdating = true;
        }

        private void DoExport(object sender, RoutedEventArgs e)
        {
            var fileName = string.Format(
                    CultureInfo.InvariantCulture,
                    "{0}\\Export_{1:MM-dd-yyyy_HH-mm-ss}.txt",
                    Path.GetTempPath().TrimEnd(Path.DirectorySeparatorChar),
                    DateTime.UtcNow);
            _excelExporter.Export(Presenter, fileName, Infragistics.Documents.Excel.WorkbookFormat.Excel2007, _exportOptions);
            OpenExcel(fileName);
        }
    }
}
